#
# rootpasword-tui.py: text mode authentication setup dialogs
#
# Copyright 2006 Red Hat, Inc.
#
# Author: Paul Nasrat <pnasrat@redhat.com>
#
# This software may be freely redistributed under the terms of the GNU
# library public license.
#
# You should have received a copy of the GNU Library Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
#

import libuser
from snack import *
from rhpl.translate import _

class RootPasswordWindow:
    def __init__(self, screen):
             
        
        self.rootPW = ""
        self.screen = screen

        self.toplevel = GridFormHelp (self.screen, _("Root Password"), "rootpw", 1, 3)

        self.toplevel.add (TextboxReflowed(37, _("Pick a root password. You must "
				"type it twice to ensure you know "
				"what it is and didn't make a mistake "
				"in typing. Remember that the "
				"root password is a critical part "
				"of system security!")), 0, 0, (0, 0, 0, 1))


        self.pwentry = Entry (24, password = 1, text = self.rootPW)
        self.pwconfirm = Entry (24, password = 1, text = self.rootPW)
        self.passgrid = Grid (2, 2)
        self.passgrid.setField (Label (_("Password:")), 0, 0, (0, 0, 1, 0), anchorLeft = 1)
        self.passgrid.setField (Label (_("Password (confirm):")), 0, 1, (0, 0, 1, 0), anchorLeft = 1)
        self.passgrid.setField (self.pwentry, 1, 0)
        self.passgrid.setField (self.pwconfirm, 1, 1)
        self.toplevel.add (self.passgrid, 0, 1, (0, 0, 0, 1))
        
        self.bb = ButtonBar (screen, [_("OK"),_("Cancel")])
        self.toplevel.add (self.bb, 0, 2, growx = 1)

    def run(self):
        try:
            self.admin = libuser.ADMIN()
        except:
             ButtonChoiceWindow(self.screen, _("Error"),
            _("You must be root to change the root password."),
                       buttons = [ _("OK") ], width = 50)
             return -1

        self.toplevel.setCurrent (self.pwentry)
        result = self.toplevel.run()

        rc = self.bb.buttonPressed (result)
        if rc == "cancel":
            return -1

        if len (self.pwentry.value ()) < 6:
            ButtonChoiceWindow(self.screen, _("Password Length"),
            _("The root password must be at least 6 characters "
                         "long."),
                       buttons = [ _("OK") ], width = 50)
        elif self.pwentry.value () != self.pwconfirm.value ():
                ButtonChoiceWindow(self.screen, _("Password Mismatch"),
                       _("The passwords you entered were different. Please "
                         "try again."),
                       buttons = [ _("OK") ], width = 50)
        else:
            self.rootPW = self.pwentry.value ()
            userEnt = self.admin.lookupUserByName("root")
            self.admin.setpassUser(userEnt, self.rootPW, 0)
            return 0

        self.pwentry.set("") 
        self.pwconfirm.set("") 
        return 1

class childWindow:
    def __init__(self):
        screen = SnackScreen()
        self.win = RootPasswordWindow(screen)

        DONE = 0

        while not DONE:
            rc = self.win.run()
            if rc == -1:
                screen.finish()
                DONE = 1
            elif rc == 0:
                screen.finish()
                                #set rootPW
                DONE = 1

if __name__ == "__main__":
    app = childWindow()

